==> jc-1.4.0.tar.gz: java/security/AllPermission__24AllPermissionCollection.h <==
// final class java.security.AllPermission$AllPermissionCollection

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a271c48b751732fe java_security_AllPermission__24AllPermissionCollection
// @dep_class c66c17eff6c1d1e6 java_security_PermissionCollection

// header file dependencies
// @dep_header java_security_PermissionCollection

#include "java/security/PermissionCollection.h"

#ifndef _JC_java_security_AllPermission__24AllPermissionCollection_H_
#define _JC_java_security_AllPermission__24AllPermissionCollection_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_security_AllPermission__241$object;
struct _jc_java_security_Permission$object;
struct _jc_java_util_Enumeration$object;

// Typedefs
typedef struct _jc_java_security_AllPermission__24AllPermissionCollection$sub_refs	_jc_java_security_AllPermission__24AllPermissionCollection$sub_refs;
typedef struct _jc_java_security_AllPermission__24AllPermissionCollection$sub_nonrefs	_jc_java_security_AllPermission__24AllPermissionCollection$sub_nonrefs;
typedef struct _jc_java_security_AllPermission__24AllPermissionCollection$refs	_jc_java_security_AllPermission__24AllPermissionCollection$refs;
typedef struct _jc_java_security_AllPermission__24AllPermissionCollection$nonrefs	_jc_java_security_AllPermission__24AllPermissionCollection$nonrefs;
typedef struct _jc_java_security_AllPermission__24AllPermissionCollection$object	_jc_java_security_AllPermission__24AllPermissionCollection$object;

typedef struct _jc_java_security_AllPermission__24AllPermissionCollection$fields_struct	_jc_java_security_AllPermission__24AllPermissionCollection$fields_struct;
typedef const struct _jc_java_security_AllPermission__24AllPermissionCollection$vmethods	_jc_java_security_AllPermission__24AllPermissionCollection$vmethods;
typedef const struct _jc_java_security_AllPermission__24AllPermissionCollection$vtable	_jc_java_security_AllPermission__24AllPermissionCollection$vtable;
typedef const struct _jc_java_security_AllPermission__24AllPermissionCollection$vtype	_jc_java_security_AllPermission__24AllPermissionCollection$vtype;

// Class fields structure
struct _jc_java_security_AllPermission__24AllPermissionCollection$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_security_AllPermission__24AllPermissionCollection$fields_struct _jc_java_security_AllPermission__24AllPermissionCollection$class_fields;

// Constructors
extern void _jc_java_security_AllPermission__24AllPermissionCollection$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_security_AllPermission__24AllPermissionCollection$object *);
extern void _jc_java_security_AllPermission__24AllPermissionCollection$method$_init$4b7105d9b25def80(_jc_env *, struct _jc_java_security_AllPermission__24AllPermissionCollection$object *, struct _jc_java_security_AllPermission__241$object *);

// Virtual methods
extern void _jc_java_security_AllPermission__24AllPermissionCollection$method$add$a94198a5fd6a54ee(_jc_env *, struct _jc_java_security_AllPermission__24AllPermissionCollection$object *, struct _jc_java_security_Permission$object *);
extern struct _jc_object *_jc_java_security_AllPermission__24AllPermissionCollection$method$elements$7e4aa0c44b86c479(_jc_env *, struct _jc_java_security_AllPermission__24AllPermissionCollection$object *);
extern jboolean _jc_java_security_AllPermission__24AllPermissionCollection$method$implies$cbacf9d54b2bb917(_jc_env *, struct _jc_java_security_AllPermission__24AllPermissionCollection$object *, struct _jc_java_security_Permission$object *);

// Virtual method descriptors
extern _jc_method _jc_java_security_AllPermission__24AllPermissionCollection$method_info$add$a94198a5fd6a54ee;
extern _jc_method _jc_java_security_AllPermission__24AllPermissionCollection$method_info$elements$7e4aa0c44b86c479;
extern _jc_method _jc_java_security_AllPermission__24AllPermissionCollection$method_info$implies$cbacf9d54b2bb917;

// Virtual methods structure
struct _jc_java_security_AllPermission__24AllPermissionCollection$vmethods {
	void	(*add$a94198a5fd6a54ee)(_jc_env *, struct _jc_java_security_AllPermission__24AllPermissionCollection$object *, struct _jc_java_security_Permission$object *);
	struct _jc_object	*(*elements$7e4aa0c44b86c479)(_jc_env *, struct _jc_java_security_AllPermission__24AllPermissionCollection$object *);
	jboolean	(*implies$cbacf9d54b2bb917)(_jc_env *, struct _jc_java_security_AllPermission__24AllPermissionCollection$object *, struct _jc_java_security_Permission$object *);
};

// Vtable
struct _jc_java_security_AllPermission__24AllPermissionCollection$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_PermissionCollection$vmethods	java_security_PermissionCollection;
	_jc_java_security_AllPermission__24AllPermissionCollection$vmethods	java_security_AllPermission__24AllPermissionCollection;
};

// Vtype
struct _jc_java_security_AllPermission__24AllPermissionCollection$vtype {
	_jc_type			type;
	_jc_java_security_AllPermission__24AllPermissionCollection$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_AllPermission__24AllPermissionCollection$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_security_AllPermission__24AllPermissionCollection$refs {
    _jc_java_security_AllPermission__24AllPermissionCollection$sub_refs	java_security_AllPermission__24AllPermissionCollection;
    _jc_java_security_PermissionCollection$sub_refs	java_security_PermissionCollection;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_AllPermission__24AllPermissionCollection$sub_nonrefs {
	jboolean	all__5fallowed;
};

// Non-reference instance fields (object)
struct _jc_java_security_AllPermission__24AllPermissionCollection$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_PermissionCollection$sub_nonrefs	java_security_PermissionCollection;
    _jc_java_security_AllPermission__24AllPermissionCollection$sub_nonrefs	java_security_AllPermission__24AllPermissionCollection;
};

// Object instance structure
struct _jc_java_security_AllPermission__24AllPermissionCollection$object {
	_jc_java_security_AllPermission__24AllPermissionCollection$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_AllPermission__24AllPermissionCollection$vtype	*vtype;
	_jc_java_security_AllPermission__24AllPermissionCollection$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_AllPermission__24AllPermissionCollection$vtype _jc_java_security_AllPermission__24AllPermissionCollection$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_AllPermission__24AllPermissionCollection, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_AllPermission__24AllPermissionCollection$class_object;

#endif	/* _JC_java_security_AllPermission__24AllPermissionCollection_H_ */

==> jc-1.4.6.tar.gz: java/security/AllPermission__24AllPermissionCollection.h <==
// final class java.security.AllPermission$AllPermissionCollection

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class a271c48b751732fe java_security_AllPermission__24AllPermissionCollection
// @dep_class c66c17eff6c1d1e6 java_security_PermissionCollection

// header file dependencies
// @dep_header java_security_PermissionCollection

#include "java/security/PermissionCollection.h"

#ifndef _JC_java_security_AllPermission__24AllPermissionCollection_H_
#define _JC_java_security_AllPermission__24AllPermissionCollection_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_security_AllPermission__241$object;
struct _jc_java_security_Permission$object;
struct _jc_java_util_Enumeration$object;

// Typedefs
typedef struct _jc_java_security_AllPermission__24AllPermissionCollection$sub_refs	_jc_java_security_AllPermission__24AllPermissionCollection$sub_refs;
typedef struct _jc_java_security_AllPermission__24AllPermissionCollection$sub_nonrefs	_jc_java_security_AllPermission__24AllPermissionCollection$sub_nonrefs;
typedef struct _jc_java_security_AllPermission__24AllPermissionCollection$refs	_jc_java_security_AllPermission__24AllPermissionCollection$refs;
typedef struct _jc_java_security_AllPermission__24AllPermissionCollection$nonrefs	_jc_java_security_AllPermission__24AllPermissionCollection$nonrefs;
typedef struct _jc_java_security_AllPermission__24AllPermissionCollection$object	_jc_java_security_AllPermission__24AllPermissionCollection$object;

typedef struct _jc_java_security_AllPermission__24AllPermissionCollection$fields_struct	_jc_java_security_AllPermission__24AllPermissionCollection$fields_struct;
typedef const struct _jc_java_security_AllPermission__24AllPermissionCollection$vmethods	_jc_java_security_AllPermission__24AllPermissionCollection$vmethods;
typedef const struct _jc_java_security_AllPermission__24AllPermissionCollection$vtable	_jc_java_security_AllPermission__24AllPermissionCollection$vtable;
typedef const struct _jc_java_security_AllPermission__24AllPermissionCollection$vtype	_jc_java_security_AllPermission__24AllPermissionCollection$vtype;

// Class fields structure
struct _jc_java_security_AllPermission__24AllPermissionCollection$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_security_AllPermission__24AllPermissionCollection$fields_struct _jc_java_security_AllPermission__24AllPermissionCollection$class_fields;

// Constructors
extern void _jc_java_security_AllPermission__24AllPermissionCollection$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_security_AllPermission__24AllPermissionCollection$object *) _JC_JCNI_ATTR;
extern void _jc_java_security_AllPermission__24AllPermissionCollection$method$_init$4b7105d9b25def80(_jc_env *, struct _jc_java_security_AllPermission__24AllPermissionCollection$object *, struct _jc_java_security_AllPermission__241$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_security_AllPermission__24AllPermissionCollection$method$add$a94198a5fd6a54ee(_jc_env *, struct _jc_java_security_AllPermission__24AllPermissionCollection$object *, struct _jc_java_security_Permission$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_java_security_AllPermission__24AllPermissionCollection$method$elements$7e4aa0c44b86c479(_jc_env *, struct _jc_java_security_AllPermission__24AllPermissionCollection$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_security_AllPermission__24AllPermissionCollection$method$implies$cbacf9d54b2bb917(_jc_env *, struct _jc_java_security_AllPermission__24AllPermissionCollection$object *, struct _jc_java_security_Permission$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_security_AllPermission__24AllPermissionCollection$method_info$add$a94198a5fd6a54ee;
extern _jc_method _jc_java_security_AllPermission__24AllPermissionCollection$method_info$elements$7e4aa0c44b86c479;
extern _jc_method _jc_java_security_AllPermission__24AllPermissionCollection$method_info$implies$cbacf9d54b2bb917;

// Virtual methods structure
struct _jc_java_security_AllPermission__24AllPermissionCollection$vmethods {
	void	(*add$a94198a5fd6a54ee)(_jc_env *, struct _jc_java_security_AllPermission__24AllPermissionCollection$object *, struct _jc_java_security_Permission$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*elements$7e4aa0c44b86c479)(_jc_env *, struct _jc_java_security_AllPermission__24AllPermissionCollection$object *) _JC_JCNI_ATTR;
	jboolean	(*implies$cbacf9d54b2bb917)(_jc_env *, struct _jc_java_security_AllPermission__24AllPermissionCollection$object *, struct _jc_java_security_Permission$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_security_AllPermission__24AllPermissionCollection$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_PermissionCollection$vmethods	java_security_PermissionCollection;
	_jc_java_security_AllPermission__24AllPermissionCollection$vmethods	java_security_AllPermission__24AllPermissionCollection;
};

// Vtype
struct _jc_java_security_AllPermission__24AllPermissionCollection$vtype {
	_jc_type			type;
	_jc_java_security_AllPermission__24AllPermissionCollection$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_AllPermission__24AllPermissionCollection$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_security_AllPermission__24AllPermissionCollection$refs {
    _jc_java_security_AllPermission__24AllPermissionCollection$sub_refs	java_security_AllPermission__24AllPermissionCollection;
    _jc_java_security_PermissionCollection$sub_refs	java_security_PermissionCollection;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_AllPermission__24AllPermissionCollection$sub_nonrefs {
	jboolean	all__5fallowed;
};

// Non-reference instance fields (object)
struct _jc_java_security_AllPermission__24AllPermissionCollection$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_PermissionCollection$sub_nonrefs	java_security_PermissionCollection;
    _jc_java_security_AllPermission__24AllPermissionCollection$sub_nonrefs	java_security_AllPermission__24AllPermissionCollection;
};

// Object instance structure
struct _jc_java_security_AllPermission__24AllPermissionCollection$object {
	_jc_java_security_AllPermission__24AllPermissionCollection$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_AllPermission__24AllPermissionCollection$vtype	*vtype;
	_jc_java_security_AllPermission__24AllPermissionCollection$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_AllPermission__24AllPermissionCollection$vtype _jc_java_security_AllPermission__24AllPermissionCollection$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_AllPermission__24AllPermissionCollection, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_AllPermission__24AllPermissionCollection$class_object;

#endif	/* _JC_java_security_AllPermission__24AllPermissionCollection_H_ */
